@@ -1,8 +1,6 @@
 package Pcore::Core::CLI::Cmd;
 
-use Pcore qw[-role];
-
-no Pcore;
+use Pcore -role;
 
 # COMMON
 sub cli_class ($self) {
