@@ -43,7 +43,7 @@ sub _install_service ( $self, $service_name ) {
     if ($MSWIN) {
         my $wrapper = $ENV->res->get('/bin/nssm_x64.exe');
 
-        my $output = P->capture->sys( $wrapper, 'install', $service_name, 'perl.exe', $ENV->{SCRIPT_PATH} );
+        P->pm->run_capture( $wrapper, 'install', $service_name, $^X, $ENV->{SCRIPT_PATH} );
     }
     else {
         my $TMPL = <<"TXT";
