@@ -1,6 +1,6 @@
 package Pcore::Core::CLI::Opt::Daemonize;
 
-use Pcore qw[-role];
+use Pcore -role;
 
 around cli_opt => sub ( $orig, $self ) {
     my $opt = $self->$orig // {};
@@ -32,8 +32,6 @@ around cli_run => sub ( $orig, $self, $opt, @args ) {
     return $self->$orig( $opt, @args );
 };
 
-no Pcore;
-
 1;
 __END__
 =pod
