@@ -1,6 +1,8 @@
 package Pcore::Core::Dump::Dumper;
 
-use Pcore qw[-class !dump];
+use Pcore -class;
+use Pcore::Util::Scalar qw[refaddr isweak reftype blessed looks_like_number tainted];
+use Pcore::Util::Text qw[escape_scalar remove_ansi_color format_num];
 use re qw[];
 use Sort::Naturally qw[nsort];
 use Term::ANSIColor qw[colored];
@@ -68,26 +70,29 @@ our $DUMPERS = {
     },
 };
 
+sub run ( $self, @args ) {
+    return $self->_dump(@args);
+}
+
 # INTERNAL METHODS
-sub dump {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
-    my $self = shift;
+sub _dump ( $self, @ ) {
     my %args = (
         path    => q[$VAR],
         unbless => 0,
-        splice( @_, 1 ),
+        splice @_, 2,
     );
 
     local $ENV{ANSI_COLORS_DISABLED} = 1 unless $self->color;
 
-    my ( $var_type, $blessed ) = $self->_var_type( $_[0], unbless => $args{unbless} );
+    my ( $var_type, $blessed ) = $self->_var_type( $_[1], unbless => $args{unbless} );
 
     # detect var addr
     my $var_addr = qq[${var_type}_];
-    if ( ref $_[0] ) {
-        $var_addr .= P->scalar->refaddr( $_[0] );
+    if ( ref $_[1] ) {
+        $var_addr .= refaddr( $_[1] );
     }
     else {
-        $var_addr .= P->scalar->refaddr( \$_[0] );
+        $var_addr .= refaddr( \$_[1] );
     }
 
     my $res;
@@ -100,11 +105,11 @@ sub dump {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
         my $dump_method = $blessed ? 'BLESSED' : $var_type;
         $dump_method = 'UNKNOWN' if !$self->can($dump_method);
 
-        ( $res, $tags ) = $self->$dump_method( $_[0], path => $args{path}, var_type => $var_type );
+        ( $res, $tags ) = $self->$dump_method( $_[1], path => $args{path}, var_type => $var_type );
     }
 
     # weak
-    push @{$tags}, q[weak] if P->scalar->isweak( $_[0] );
+    push @{$tags}, q[weak] if isweak( $_[1] );
 
     # add tags
     $self->_add_tags( $tags, $res );
@@ -119,9 +124,9 @@ sub _var_type {
         splice( @_, 1 ),
     );
 
-    my $ref_type = P->scalar->reftype( $_[0] );
+    my $ref_type = reftype( $_[0] );
 
-    if ( my $blessed = P->scalar->blessed( $_[0] ) ) {    # blessed
+    if ( my $blessed = blessed( $_[0] ) ) {    # blessed
         if ( $args{unbless} ) {
             return $ref_type;
         }
@@ -176,7 +181,7 @@ sub _dump_blessed {
         @_,
     );
 
-    return q[blessed: ] . $self->dump( $obj, path => $args{path}, unbless => 1 );
+    return q[blessed: ] . $self->_dump( $obj, path => $args{path}, unbless => 1 );
 }
 
 sub _tied_to {
@@ -282,7 +287,7 @@ sub REF {
         @_,
     );
 
-    return colored( q[\\ ], $COLOR->{refs} ) . $self->dump( ${$ref}, path => $args{path} . q[->$*] );
+    return colored( q[\\ ], $COLOR->{refs} ) . $self->_dump( ${$ref}, path => $args{path} . q[->$*] );
 }
 
 sub SCALAR {
@@ -294,14 +299,14 @@ sub SCALAR {
     if ( !defined $_[0] ) {    # undefined value
         $res = colored( 'undef', $COLOR->{undef} );
     }
-    elsif ( P->scalar->looks_like_number( $_[0] ) ) {
-        $res = colored( $_[0], $COLOR->{number} );
+    elsif ( looks_like_number( $_[0] ) ) {
+        $res = colored( format_num( $_[0] ), $COLOR->{number} );
     }
     else {
         my $item         = $_[0];                  # scalar become untied
         my $bytes_length = bytes::length($item);
         my $length       = length $item;
-        P->text->escape_scalar( $item, esc_color => $COLOR->{escaped}, reset_color => $COLOR->{string} );
+        escape_scalar( $item, esc_color => $COLOR->{escaped}, reset_color => $COLOR->{string} );
 
         if ( utf8::is_utf8($item) ) {              # characters
             push @{$tags}, q[UTF8];
@@ -325,7 +330,7 @@ sub SCALAR {
         }
 
         push @{$tags}, q[bytes::len = ] . $bytes_length;
-        push @{$tags}, q[tied to ] . ref tied $_[0] if P->scalar->tainted( $_[0] );
+        push @{$tags}, q[tied to ] . ref tied $_[0] if tainted( $_[0] );
 
         $res = q["] . colored( $item, $COLOR->{string} ) . q["];
     }
@@ -356,7 +361,7 @@ sub ARRAY {
             my $index = sprintf( q[%-*s], $max_index_length, qq[[$i]] ) . q[ ];
             $res .= $self->_indent . colored( $index, $COLOR->{array} );
 
-            my $el = $self->dump( $array_ref->[$i], path => $args{path} . "->[$i]" );
+            my $el = $self->_dump( $array_ref->[$i], path => $args{path} . "->[$i]" );
             $self->_indent_text($el);
 
             $res .= $el;
@@ -388,14 +393,15 @@ sub HASH {
         $res = colored( '{', $COLOR->{refs} ) . $LF;
         my $keys;
         my $max_length = 0;
-        for ( nsort keys %{$hash_ref} ) {
+        for ( nsort keys $hash_ref->%* ) {
             my $indexed_key = {
                 raw_key     => $_,
-                escaped_key => P->text->escape_scalar( $_, esc_color => $COLOR->{escaped}, reset_color => $COLOR->{hash} ),
+                escaped_key => \escape_scalar( $_, esc_color => $COLOR->{escaped}, reset_color => $COLOR->{hash} ),
             };
 
             $indexed_key->{escaped_key_nc} = $indexed_key->{escaped_key}->$*;
-            P->text->remove_ansi_color( $indexed_key->{escaped_key_nc} );
+
+            remove_ansi_color $indexed_key->{escaped_key_nc};
 
             $indexed_key->{escaped_key_nc_len} = length $indexed_key->{escaped_key_nc};
 
@@ -410,7 +416,7 @@ sub HASH {
             $res .= $self->_indent . q["] . colored( $keys->[$i]->{escaped_key}->$*, $COLOR->{hash} ) . q["];
             $res .= sprintf q[%*s], ( $max_length - $keys->[$i]->{escaped_key_nc_len} + 4 ), q[ => ];
 
-            my $el = $self->dump( $hash_ref->{ $keys->[$i]->{raw_key} }, path => $args{path} . '->{"' . $keys->[$i]->{escaped_key_nc} . '"}' );
+            my $el = $self->_dump( $hash_ref->{ $keys->[$i]->{raw_key} }, path => $args{path} . '->{"' . $keys->[$i]->{escaped_key_nc} . '"}' );
             $self->_indent_text($el);
 
             $res .= $el;
@@ -516,7 +522,9 @@ sub LVALUE {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    1 │ 75, 226, 285         │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
+## │    3 │ 396                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    1 │ 80, 231, 290         │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
