@@ -1,13 +1,10 @@
 package Pcore::Core::Exception;
 
-use Pcore qw[-export];
-
-use Pcore::Core::Exception::Object;
+use Pcore -export => {    #
+    DEFAULT => [qw[croak cluck try catch]],
+};
 use Carp qw[];
-
-our @EXPORT_OK   = qw[croak cluck propagate try catch];
-our %EXPORT_TAGS = ();
-our @EXPORT      = @EXPORT_OK;
+use Pcore::Core::Exception::Object;
 
 our $IGNORE_ERRORS = 1;    # do not write errors to error log channel by default
 
@@ -23,13 +20,10 @@ sub CORE_INIT {
 
     $SIG{__WARN__} = \&SIGWARN;  ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
-    *CORE::GLOBAL::die = \&GLOBAL_DIE;
-
-    *CORE::GLOBAL::warn = \&GLOBAL_WARN;
-
     # we don't need stacktrace from Error::TypeTiny exceptions
     $Error::TypeTiny::StackTrace = 0;
 
+    # redefine Carp::longmess, Carp::shotmess, disable stack trace
     {
         no warnings qw[redefine];
 
@@ -47,141 +41,121 @@ sub CORE_INIT {
 }
 
 sub SIGINT {
-    exit;
+    exit 128 + 2;
 }
 
 sub SIGTERM {
-    exit;
+    exit 128 + 15;
 }
 
 # SIGNALS
-# http://perldoc.perl.org/perlvar.html#%25SIG
-# The routine indicated by $SIG{__DIE__} is called when a fatal exception is about to be thrown. The error message is passed as the first argument. When a __DIE__ hook routine returns, the exception processing continues as it would have in the absence of the hook, unless the hook routine itself exits via a goto &sub , a loop exit, or a die(). The __DIE__ handler is explicitly disabled during the call, so that you can die from a __DIE__ handler. Similarly for __WARN__.
-# die in BEGIN generates parsing error, no matter in eval or not;
-# compile-time errors / warnings belongs to namespace, from which compilation was requested;
 sub SIGDIE {
-    my $e = Pcore::Core::Exception::Object->new_exception( $_[0], level => 'ERROR', skip_frames => 1, trace => 1 );
+    my $e = Pcore::Core::Exception::Object->new( $_[0], level => 'ERROR', skip_frames => 1, trace => 1 );
 
-    CORE::die $_[0] unless defined $e;    # fallback to standart behavior if exception wasn't created for some reasons
+    if ( !defined $^S || $^S ) {    # ERROR, !defined $^S - parsing module, eval, or main program, true - executing an eval
+        {
+            local $@;
 
-    if ( !defined $^S || $^S ) {          # ERROR, catched in eval
-        $e->send_log( level => 'ERROR' ) unless $IGNORE_ERRORS;
+            eval {                  #
+                $e->sendlog( channel => 'error' ) unless $IGNORE_ERRORS;
+            };
+        }
 
-        return CORE::die $e;              # terminate standart die behavior
+        return CORE::die $e;        # set $@ = $e
     }
-    else {                                # FATAL
-        $e->send_log( level => 'FATAL', force => 1 );
+    else {                          # FATAL
+        {
+            local $@;
+
+            eval {                  #
+                $e->sendlog( channel => 'fatal', force => 1 );
+            };
+        }
 
         exit $e->exit_code;
     }
 }
 
 sub SIGWARN {
-    my $e = Pcore::Core::Exception::Object->new_exception( $_[0], level => 'WARN', skip_frames => 1, trace => 1 );
+    my $e = Pcore::Core::Exception::Object->new( $_[0], level => 'WARN', skip_frames => 1, trace => 1 );
 
-    # fallback to standart behavior if exception wasn't created for some reasons
-    unless ( defined $e ) {
-        CORE::warn $_[0];
+    {
+        local $@;
 
-        return;
+        $e->sendlog( channel => 'warn' );
     }
 
-    $e->send_log( level => 'WARN' );
-
-    return;    # terminate standart warn behavior
-}
-
-# HOOKS
-sub GLOBAL_DIE {
-    my $msg = defined $_[0] ? $_[0] : defined $@ ? $@ : 'Died';
-
-    my $e = Pcore::Core::Exception::Object->new_exception( $msg, level => 'ERROR', skip_frames => 1, trace => 1, from_hook => 1 );
-
-    if ( defined $e ) {
-        return CORE::die $e;
-    }
-    else {
-        return CORE::die $msg;
-    }
-}
-
-sub GLOBAL_WARN {
-    my $msg = defined $_[0] ? $_[0] : defined $@ ? $@ : q[Warning: something's wrong];
-
-    my $e = Pcore::Core::Exception::Object->new_exception( $msg, level => 'WARN', skip_frames => 1, trace => 1, from_hook => 1 );
-
-    if ( defined $e ) {
-        return CORE::warn $e;
-    }
-    else {
-        return CORE::warn $msg;
-    }
+    return;    # skip standard warn behaviour
 }
 
 # die without trace
 sub croak {
-    my $msg = defined $_[0] ? $_[0] : defined $@ ? $@ : 'Died';
+    my $msg;
 
-    my $e = Pcore::Core::Exception::Object->new_exception( $msg, level => 'ERROR', skip_frames => 1, trace => 0, from_hook => 1 );
-
-    if ( defined $e ) {
-        return CORE::die $e;
-    }
-    else {
-        return CORE::die $msg;
-    }
-}
-
-# warn with trace
-sub cluck {
-    my $msg = defined $_[0] ? $_[0] : defined $@ ? $@ : q[Warning: something's wrong];
-
-    my $e = Pcore::Core::Exception::Object->new_exception( $msg, level => 'WARN', skip_frames => 1, trace => 1, from_hook => 1 );
-
-    if ( defined $e ) {
-        return CORE::warn $e;
-    }
-    else {
-        return CORE::warn $msg;
-    }
-}
-
-# propagate
-sub propagate {
-    my $msg = defined $_[0] ? $_[0] : defined $@ ? $@ : 'PROPAGATED';
-
-    return Pcore::Core::Exception::Object->new_exception( $msg, level => 'ERROR', skip_frames => 1, trace => 1, propagated => 1 )->propagate;
-}
-
-# TRY
-sub try : prototype(&@) {
-    my ( $try, @code_refs ) = @_;
-
-    my $wantarray = wantarray;
-    my $catch;
-    foreach my $code_ref (@code_refs) {
-        my $ref = ref $code_ref;
-
-        if ( $ref eq 'Pcore::Core::ExceptionCatch' ) {
-            die 'Invalid usage, only one catch block allowed' if $catch;
-
-            $catch = ${$code_ref};
+    if (@_) {
+        if ( @_ > 1 ) {
+            $msg = join q[], @_;
         }
         else {
-            die "Unknown code ref type given '${ref}'. Check your usage & try again";
+            $msg = $_[0];
         }
     }
+    elsif ($@) {
+        $msg = $@ . ' ...propagated';
+    }
+    else {
+        $msg = 'Died';
+    }
 
-    P->class->set_subname( '::try' => $try );
-    P->class->set_subname( '::catch' => $catch ) if $catch;
+    my $e = Pcore::Core::Exception::Object->new( $msg, level => 'ERROR', skip_frames => 1, trace => 0 );
+
+    return CORE::die $e;
+}
+
+# warn without trace
+sub cluck {
+    my $msg;
+
+    if (@_) {
+        if ( @_ > 1 ) {
+            $msg = join q[], @_;
+        }
+        else {
+            $msg = $_[0];
+        }
+    }
+    elsif ($@) {
+        $msg = $@ . ' ...caught';
+    }
+    else {
+        $msg = q[Warning: something's wrong];
+    }
+
+    my $e = Pcore::Core::Exception::Object->new( $msg, level => 'WARN', skip_frames => 1, trace => 0 );
+
+    return CORE::warn $e;
+}
+
+# create and throw new propagated exception
+sub propagate ($msg) {
+    return Pcore::Core::Exception::Object->new( $msg, level => 'ERROR', skip_frames => 1, trace => 1, propagated => 1 )->propagate;
+}
+
+# TRY / CATCH
+sub try ( $try, $catch = undef ) : prototype(&@) {
+    my $wantarray = wantarray;
 
-    # eval
-    my $prev_error = $@;
     my @res;
-    my $failed = not eval {
-        local $SIG{__DIE__} = \&SIGDIE;
 
-        $@ = $prev_error;    ## no critic qw[Variables::RequireLocalizedPunctuationVars] make previous $@ accesible inside eval, eval clean $@ before start
+    my $prev_error = $@;
+
+    my $failed = not eval {
+
+        # we should create exception object manually, because __DIE__ will not work if try/catch will called from __DIE__ handler
+        local $SIG{__DIE__} = undef;
+
+        # make previous $@ accesible inside eval, eval clean $@ before start
+        $@ = $prev_error;    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
         if ($wantarray) {
             @res = $try->();
@@ -196,10 +170,10 @@ sub try : prototype(&@) {
         return 1;
     };
 
-    my $e = $@;
-
     # error handling
     if ($failed) {
+        my $e = Pcore::Core::Exception::Object->new( $@, level => 'ERROR', skip_frames => 2, trace => 1 );
+
         if ($catch) {
             if ($wantarray) {
                 @res = $catch->($e);
@@ -213,7 +187,9 @@ sub try : prototype(&@) {
         }
 
         if ( $e->is_propagated ) {
-            $@ = q[];    ## no critic qw[Variables::RequireLocalizedPunctuationVars], clear $@ because handled propagated exception treat as not error
+
+            # clear $@ because handled propagated exception treat as not an error
+            $@ = q[];    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
             $e->propagate unless $e->_stop_propagate;
         }
@@ -222,13 +198,23 @@ sub try : prototype(&@) {
     return $wantarray ? @res : $res[0];
 }
 
-sub catch : prototype(&@) {
-    my $code = shift;
-
-    return ( bless( \$code, 'Pcore::Core::ExceptionCatch' ), @_ );
+sub catch ($code) : prototype(&) {
+    return $code;
 }
 
 1;
+## -----SOURCE FILTER LOG BEGIN-----
+##
+## PerlCritic profile "pcore-script" policy violations:
+## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
+## │ Sev. │ Lines                │ Policy                                                                                                         │
+## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
+## │    3 │ 57, 68, 83           │ Variables::RequireInitializationForLocalVars - "local" variable not initialized                                │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    3 │ 59, 70               │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
+## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+##
+## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
