@@ -1,19 +1,17 @@
 package Pcore::Core::I18N;
 
-use Pcore qw[-export];
-
-our @EXPORT_OK   = qw[i18n i18n_locale];
-our %EXPORT_TAGS = (                       #
-    CORE => [qw[i18n_locale]]
-);
-our @EXPORT = qw[i18n];
+use Pcore -export => {
+    CORE    => [qw[i18n_locale]],
+    DEFAULT => [qw[i18n]],
+};
+use Pcore::Util::Text qw[decode_utf8];
 
 our $LOCALE    = 'en_US';
 our $LOCATIONS = [];
 our $CACHE     = {};
 
 sub CORE_INIT {
-    if ( my $i18n_res = $PROC->res->get_storage('i18n') ) {
+    if ( my $i18n_res = $ENV->res->get_storage('i18n') ) {
         for my $path ( $i18n_res->@* ) {
             _add_location($path);
         }
@@ -252,7 +250,7 @@ sub _t {
         $trans = $trans[$plural] if defined $trans[$plural];
     }
 
-    P->text->decode($trans);
+    decode_utf8 $trans;
 
     return $trans;
 }
@@ -264,17 +262,17 @@ sub _t {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 90                   │ Subroutines::ProhibitExcessComplexity - Subroutine "_load_catalog" with high complexity score (26)             │
+## │    3 │ 88                   │ Subroutines::ProhibitExcessComplexity - Subroutine "_load_catalog" with high complexity score (26)             │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 183, 197             │ RegularExpressions::ProhibitComplexRegexes - Split long regexps into smaller qr// chunks                       │
+## │    3 │ 181, 195             │ RegularExpressions::ProhibitComplexRegexes - Split long regexps into smaller qr// chunks                       │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 108, 111             │ ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     │
+## │    2 │ 106, 109             │ ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 135                  │ ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            │
+## │    2 │ 133                  │ ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 116, 130, 131        │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    1 │ 114, 128, 129        │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 179                  │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
+## │    1 │ 177                  │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -289,7 +287,7 @@ Pcore::Core::I18N - P internationalization subsystem.
 
 =head1 SYNOPSIS
 
-    GO->I18N->add_location($PROC->{I18N_DIR});
+    GO->I18N->add_location($ENV->{I18N_DIR});
     GO->I18N->locale('ru_RU');
 
 =head1 Config strings internationalization
@@ -305,8 +303,8 @@ Pcore::Core::I18N - P internationalization subsystem.
 
 Для ресолвинга интернациональных строк в конфиге использовать вызов:
 
-    i18n($PROC->{string});
-    i18n($PROC->{plural_string}, $plural_value); $plural_value - числовое значение множественной формы
+    i18n($ENV->{string});
+    i18n($ENV->{plural_string}, $plural_value); $plural_value - числовое значение множественной формы
 
 
 =head1 Template toolkit templates internationalization
