@@ -31,57 +31,98 @@ sub _build_api ($self) {
 
 sub get ( $self, @ ) {
     my %args = (
-        id       => undef,
-        all      => undef,
-        open     => undef,
-        resolved => undef,
-        closed   => undef,
+        id        => undef,
+        active    => undef,
+        new       => undef,
+        open      => undef,
+        resolved  => undef,
+        closed    => undef,
+        hold      => undef,
+        invalid   => undef,
+        duplicate => undef,
+        wontfix   => undef,
         splice @_, 1,
     );
 
-    my $id = $args{id};
+    my $status = {};
+
+    $status->@{qw[new open resolved closed]} = () if $args{active};
+
+    if ( $args{new} || $args{open} ) {
+        if ( !$args{id} ) {
+            $status->@{qw[new open]} = ();
+        }
+        else {
+            $status->{new} = undef if $args{new};
+
+            $status->{open} = undef if $args{open};
+        }
+    }
+
+    $status->{resolved} = undef if $args{resolved};
+
+    $status->{closed} = undef if $args{closed};
+
+    $status->{'on hold'} = undef if $args{hold};
+
+    $status->{invalid} = undef if $args{invalid};
+
+    $status->{duplicate} = undef if $args{duplicate};
+
+    $status->{wontfix} = undef if $args{wontfix};
+
+    $status->@{qw[new open]} = () if !$args{id} && !$status->%*;
 
     my $cv = AE::cv;
 
-    my $status;
+    my @status = keys $status->%*;
 
-    if ( $args{all} ) {
-        $status = [ 'new', 'open', 'resolved', 'closed' ];
-    }
-    elsif ( $args{open} ) {
-        $status = [ 'new', 'open' ];
-    }
-    elsif ( $args{resolved} ) {
-        $status = 'resolved';
-    }
-    elsif ( $args{closed} ) {
-        $status = 'closed';
+    if ( $args{id} && @status ) {
+
+        # impossible to set multiple statuses
+        croak q[Can't set multiply issue statuses] if @status > 1;
+
+        my $issue;
+
+        $self->api->set_issue_status(
+            $args{id},
+            $status[0],
+            sub ($res) {
+                $issue = $res;
+
+                $cv->send;
+
+                return;
+            }
+        );
+
+        $cv->recv;
+
+        return $issue;
     }
     else {
-        $status = [ 'new', 'open' ];
+        my $issues;
+
+        $self->api->issues(
+            id        => $args{id},
+            status    => \@status,
+            milestone => $args{milestone},
+            sub ($res) {
+                $issues = $res;
+
+                $cv->send;
+
+                return;
+            }
+        );
+
+        $cv->recv;
+
+        return $issues;
     }
-
-    my $issues;
-
-    $self->api->issues(
-        id      => $id,
-        status  => $status,
-        version => undef,
-        sub ($res) {
-            $issues = $res;
-
-            $cv->send;
-
-            return;
-        }
-    );
-
-    $cv->recv;
-
-    return $issues;
 }
 
-sub print_issues ( $self, $issues ) {
+sub print_issues ( $self, $issues, $content = 1 ) {
     if ( !$issues ) {
         say 'No issues';
     }
@@ -97,16 +138,18 @@ sub print_issues ( $self, $issues ) {
 
             $tbl->add_row( $issue->{local_id}, $issue->priority_color, $issue->status_color, $issue->kind_color, $issue->{title} );
 
-            say $tbl->render;
+            print $tbl->render;
 
-            say $LF, $issue->{content} || 'No content';
+            say $LF, $issue->{content} || 'No content' if $content;
         }
         else {
             for my $issue ( sort { $b->utc_last_updated_ts <=> $a->utc_last_updated_ts or $b->priority_id <=> $a->priority_id } $issues->@* ) {
                 $tbl->add_row( $issue->{local_id}, $issue->priority_color, $issue->status_color, $issue->kind_color, $issue->{title} );
             }
 
-            say $tbl->render;
+            print $tbl->render;
+
+            say 'max. 50 first issues shown';
         }
     }
 
@@ -117,6 +160,10 @@ sub create_version ( $self, $ver, $cb ) {
     return $self->api->create_version( $ver, $cb );
 }
 
+sub create_milestone ( $self, $milestone, $cb ) {
+    return $self->api->create_milestone( $milestone, $cb );
+}
+
 1;
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
@@ -124,9 +171,11 @@ sub create_version ( $self, $ver, $cb ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
+## │    3 │ 74, 78               │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    2 │ 24                   │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 105                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
+## │    1 │ 146                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
