@@ -1,12 +1,10 @@
 package Pcore::Dist::CLI::Create;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::Dist;
 
 with qw[Pcore::Core::CLI::Cmd];
 
-no Pcore;
-
 # CLI
 sub cli_abstract ($self) {
     return 'create new distribution';
@@ -36,7 +34,7 @@ sub cli_arg ($self) {
 sub cli_run ( $self, $opt, $arg, $rest ) {
     $opt->{namespace} = $arg->{namespace};
 
-    $opt->{path} = $PROC->{START_DIR};
+    $opt->{path} = $ENV->{START_DIR};
 
     if ( my $dist = Pcore::Dist->create( $opt->%* ) ) {
         return;
@@ -55,7 +53,7 @@ sub cli_run ( $self, $opt, $arg, $rest ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 41                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 39                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
