@@ -1,11 +1,9 @@
 package Pcore::Dist::CLI::Setup;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::Core::CLI::Cmd];
 
-no Pcore;
-
 sub cli_abstract ($self) {
     return 'setup pcore.ini';
 }
@@ -17,7 +15,7 @@ sub cli_run ( $self, $opt, $arg, $rest ) {
 }
 
 sub run ($self) {
-    require Pcore::Dist::Build;
+    state $init = !!require Pcore::Dist::Build;
 
     Pcore::Dist::Build->new->setup;
 
