@@ -1,6 +1,6 @@
 package Pcore::HTTP::Message;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::HTTP::Message::Headers;
 
 has status => ( is => 'ro', isa => PositiveInt, writer => 'set_status', default => 200 );
@@ -12,12 +12,7 @@ has content_length => ( is => 'rwp', isa => PositiveOrZeroInt, default => 0, ini
 
 has buf_size => ( is => 'ro', isa => PositiveOrZeroInt, default => 0 );    # write body to fh if body length > this value, 0 - always store in memory, 1 - always store to file
 
-no Pcore;
-
-sub BUILD {
-    my $self = shift;
-    my $args = shift;
-
+sub BUILD ( $self, $args ) {
     $self->headers->add( $args->{headers} ) if $args->{headers};
 
     $self->set_body( $args->{body} ) if $args->{body};
@@ -48,7 +43,7 @@ sub _body_to_psgi ($self) {
 # body chunked if body is FH or FilePath, and size > $self->buf_size;
 # body is multipart if has content parts with different content-types;
 # universal response coderef;
-sub body_to_ae_http ($self) {
+sub body_to_http ($self) {
     return $self->body;
 }
 
