@@ -1,6 +1,7 @@
 package Pcore::Src;
 
-use Pcore qw[-class];
+use Pcore -class;
+use Pcore::Util::Text qw[decode_utf8];
 use Pcore::Src::File;
 use Term::ANSIColor qw[:constants];
 
@@ -96,7 +97,7 @@ sub cli_arg ($self) {
 }
 
 sub cli_run ( $self, $opt, $arg, $rest ) {
-    P->file->chdir( $PROC->{START_DIR} );
+    P->file->chdir( $ENV->{START_DIR} );
 
     my $exit_code = try {
         my $src = Pcore::Src->new(
@@ -315,7 +316,7 @@ sub _report_file ( $self, $res, $max_path_len ) {
 
     # print report
     print $hl;
-    printf q[%-*s], $max_path_len, P->text->decode( $res->path->to_string, encoding => $Pcore::WIN_ENC )->$*;
+    printf q[%-*s], $max_path_len, decode_utf8( $res->path->to_string, encoding => $Pcore::WIN_ENC );
     print q[ ] x 2;
     print RESET;
 
@@ -370,7 +371,7 @@ sub _wrap_color ( $self, $str, $color ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 323                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 324                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
