@@ -1,12 +1,10 @@
 package Pcore::Util::File::Tree;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::Util::File::Tree::File;
 
 has files => ( is => 'lazy', isa => HashRef [ InstanceOf ['Pcore::Util::File::Tree::File'] ], default => sub { {} }, init_arg => undef );
 
-no Pcore;
-
 sub add_dir ( $self, $dir, $root = undef ) {
     $dir = P->path( $dir, is_dir => 1 )->realpath->to_string;
 
@@ -77,7 +75,7 @@ sub render_tmpl ( $self, $tmpl_args ) {
 sub write_to ( $self, $target_path, @ ) {
     my %args = (
         manifest => undef,
-        @_[ 2 .. $#_ ],
+        splice @_, 2,
     );
 
     for my $file ( values $self->files->%* ) {
@@ -95,7 +93,7 @@ sub write_to_temp ( $self, @ ) {
         base     => undef,
         tmpl     => undef,
         manifest => undef,
-        @_[ 1 .. $#_ ],
+        splice @_, 1,
     );
 
     my $tempdir = P->file->tempdir(    #
@@ -115,7 +113,7 @@ sub write_to_temp ( $self, @ ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 62, 70, 83, 88       │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 60, 68, 81, 86       │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
