@@ -1,11 +1,11 @@
 package Pcore::Util::Path;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Storable qw[];
-use Scalar::Util qw[blessed];    ## no critic qw[Modules::ProhibitEvilModules]
+use Pcore::Util::Scalar qw[blessed];
 use Pcore::Util::URI;
 
-use overload                     #
+use overload    #
   q[""] => sub {
     return $_[0]->to_string;
   },
@@ -50,7 +50,7 @@ around new => sub ( $orig, $self, $path = q[], @ ) {
         base     => q[],
         lazy     => 0,
         from_uri => 0,
-        @_[ 3 .. $#_ ],
+        splice @_, 3,
     );
 
     $self = ref $self if blessed $self;
@@ -246,19 +246,10 @@ around mime_type => sub ( $orig, $self, $shebang = undef ) {
     return $self->{mime_type} || $self->default_mime_type;
 };
 
-no Pcore;
-
 # apache MIME types
 # http://svn.apache.org/viewvc/httpd/httpd/trunk/docs/conf/mime.types?view=co
 our $MIME_TYPES;
 
-# Pcore::Util interface
-sub NEW {
-    shift;
-
-    return __PACKAGE__->new(@_);
-}
-
 sub _build_to_string ($self) {
     my $path = $self->path;
 
@@ -419,16 +410,16 @@ sub is_root ($self) {
 # MIME
 sub _get_mime_types ($self) {
     unless ($MIME_TYPES) {
-        $MIME_TYPES = P->cfg->load( $PROC->res->get('/data/mime.perl') );
+        $MIME_TYPES = P->cfg->load( $ENV->res->get('/data/mime.perl') );
 
         # index MIME categories
         for my $suffix ( keys $MIME_TYPES->{suffix}->%* ) {
             my $type;
 
-            if ( ref $MIME_TYPES->{suffix}->{$suffix} eq 'HASH' ) {
-                $type = $MIME_TYPES->{suffix}->{$suffix}->{type};
+            if ( ref $MIME_TYPES->{suffix}->{$suffix} eq 'ARRAY' ) {
+                $type = $MIME_TYPES->{suffix}->{$suffix}->[0];
 
-                $MIME_TYPES->{category}->{$type} = $MIME_TYPES->{suffix}->{$suffix}->{category} if $MIME_TYPES->{suffix}->{$suffix}->{category};
+                $MIME_TYPES->{category}->{$type} = $MIME_TYPES->{suffix}->{$suffix}->[1] if $MIME_TYPES->{suffix}->{$suffix}->[1];
 
                 $MIME_TYPES->{suffix}->{$suffix} = $type;
             }
@@ -447,7 +438,7 @@ sub _get_mime_types ($self) {
 
 sub _build_mime_category ($self) {
     if ( $self->mime_type ) {
-        return $self->_mime_types->{category}->{ $self->mime_type } // q[];
+        return $self->_get_mime_types->{category}->{ $self->mime_type } // q[];
     }
     else {
         return q[];
@@ -478,9 +469,9 @@ sub TO_DUMP {
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    3 │ 19                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 233, 425             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 233, 416             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 372                  │ ValuesAndExpressions::ProhibitNoisyQuotes - Quotes used with a noisy string                                    │
+## │    2 │ 363                  │ ValuesAndExpressions::ProhibitNoisyQuotes - Quotes used with a noisy string                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
