@@ -1,7 +1,7 @@
 package Pcore::Util::Perl::Module;
 
-use Pcore qw[-class];
-use Config qw[];
+use Pcore -class;
+use Config;
 
 has name => ( is => 'lazy', isa => Maybe [Str] );    # Module/Name.pm
 has content => ( is => 'lazy', isa => ScalarRef, clearer => 1 );
@@ -58,8 +58,6 @@ around new => sub ( $orig, $self, $module, @inc ) {
     return;
 };
 
-no Pcore;
-
 # CLASS METHODS
 sub lib_is_dist ( $self, $lib ) {
     if ( -d "$lib/auto/" ) {
@@ -172,11 +170,11 @@ sub _build_auto_deps ($self) {
 
     my $auto_path = 'auto/' . $name->dirname . $name->filename_base . q[/];
 
-    my $so_filename = $name->filename_base . q[.] . $Config::Config{dlext};
+    my $so_filename = $name->filename_base . q[.] . $Config{dlext};
 
     my $deps;
 
-    for my $lib ( map { P->path($_)->to_string } $PROC->{INLINE_DIR} . 'lib/', @INC ) {
+    for my $lib ( map { P->path($_)->to_string } $ENV->{INLINE_DIR} . 'lib/', @INC ) {
         if ( -f "$lib/$auto_path" . $so_filename ) {
             $deps->{ $auto_path . $so_filename } = "$lib/$auto_path" . $so_filename;
 
@@ -215,9 +213,9 @@ sub clear ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 147                  │ RegularExpressions::ProhibitComplexRegexes - Split long regexps into smaller qr// chunks                       │
+## │    3 │ 145                  │ RegularExpressions::ProhibitComplexRegexes - Split long regexps into smaller qr// chunks                       │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 180                  │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
+## │    3 │ 178                  │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
